Class: Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb

Overview

Overrides the top-level autoscaling configuration for the replicas identified by replica_selection. All fields in this message are optional. Any unspecified fields will use the corresponding values from the top-level autoscaling configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaling_limits::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingLimits

Returns Optional. If specified, overrides the min/max limit in the top-level autoscaling configuration for the selected replicas.

Returns:



449
450
451
452
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 449

class AutoscalingConfigOverrides
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#autoscaling_target_high_priority_cpu_utilization_percent::Integer

Returns Optional. If specified, overrides the autoscaling target high_priority_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas.

Returns:

  • (::Integer)

    Optional. If specified, overrides the autoscaling target high_priority_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas.



449
450
451
452
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 449

class AutoscalingConfigOverrides
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#autoscaling_target_total_cpu_utilization_percent::Integer

Returns Optional. If specified, overrides the autoscaling target total_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas.

Returns:

  • (::Integer)

    Optional. If specified, overrides the autoscaling target total_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas.



449
450
451
452
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 449

class AutoscalingConfigOverrides
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disable_high_priority_cpu_autoscaling::Boolean

Returns Optional. If true, disables high priority CPU autoscaling for the selected replicas and ignores high_priority_cpu_utilization_percent in the top-level autoscaling configuration.

When setting this field to true, setting autoscaling_target_high_priority_cpu_utilization_percent field to a non-zero value for the same replica is not supported.

If false, the autoscaling_target_high_priority_cpu_utilization_percent field in the replica will be used if set to a non-zero value. Otherwise, the high_priority_cpu_utilization_percent field in the top-level autoscaling configuration will be used.

Setting both disable_high_priority_cpu_autoscaling and disable_total_cpu_autoscaling to true for the same replica is not supported.

Returns:



449
450
451
452
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 449

class AutoscalingConfigOverrides
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disable_total_cpu_autoscaling::Boolean

Returns Optional. If true, disables total CPU autoscaling for the selected replicas and ignores total_cpu_utilization_percent in the top-level autoscaling configuration.

When setting this field to true, setting autoscaling_target_total_cpu_utilization_percent field to a non-zero value for the same replica is not supported.

If false, the autoscaling_target_total_cpu_utilization_percent field in the replica will be used if set to a non-zero value. Otherwise, the total_cpu_utilization_percent field in the top-level autoscaling configuration will be used.

Setting both disable_high_priority_cpu_autoscaling and disable_total_cpu_autoscaling to true for the same replica is not supported.

Returns:



449
450
451
452
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 449

class AutoscalingConfigOverrides
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end