Class: Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb

Overview

The autoscaling targets for an instance.

Instance Attribute Summary collapse

Instance Attribute Details

#high_priority_cpu_utilization_percent::Integer

Returns Optional. The target high priority cpu utilization percentage that the autoscaler should be trying to achieve for the instance. This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 90] inclusive. If not specified or set to 0, the autoscaler skips scaling based on high priority CPU utilization.

Returns:

  • (::Integer)

    Optional. The target high priority cpu utilization percentage that the autoscaler should be trying to achieve for the instance. This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 90] inclusive. If not specified or set to 0, the autoscaler skips scaling based on high priority CPU utilization.



366
367
368
369
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 366

class AutoscalingTargets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#storage_utilization_percent::Integer

Returns Required. The target storage utilization percentage that the autoscaler should be trying to achieve for the instance. This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 99] inclusive.

Returns:

  • (::Integer)

    Required. The target storage utilization percentage that the autoscaler should be trying to achieve for the instance. This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 99] inclusive.



366
367
368
369
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 366

class AutoscalingTargets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_cpu_utilization_percent::Integer

Returns Optional. The target total CPU utilization percentage that the autoscaler should be trying to achieve for the instance. This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 90] inclusive. If not specified or set to 0, the autoscaler skips scaling based on total CPU utilization. If both high_priority_cpu_utilization_percent and total_cpu_utilization_percent are specified, the autoscaler provisions the larger of the two required compute capacities to satisfy both targets.

Returns:

  • (::Integer)

    Optional. The target total CPU utilization percentage that the autoscaler should be trying to achieve for the instance. This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 90] inclusive. If not specified or set to 0, the autoscaler skips scaling based on total CPU utilization. If both high_priority_cpu_utilization_percent and total_cpu_utilization_percent are specified, the autoscaler provisions the larger of the two required compute capacities to satisfy both targets.



366
367
368
369
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 366

class AutoscalingTargets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end