Class: Google::Cloud::Spanner::Admin::Instance::V1::CreateInstanceMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb

Overview

Metadata type for the operation returned by CreateInstance.

Instance Attribute Summary collapse

Instance Attribute Details

#cancel_time::Google::Protobuf::Timestamp

Returns The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again.

Returns:

  • (::Google::Protobuf::Timestamp)

    The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again.



962
963
964
965
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time::Google::Protobuf::Timestamp

Returns The time at which this operation failed or was completed successfully.

Returns:



962
963
964
965
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expected_fulfillment_period::Google::Cloud::Spanner::Admin::Instance::V1::FulfillmentPeriod

Returns The expected fulfillment period of this create operation.

Returns:



962
963
964
965
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::Google::Cloud::Spanner::Admin::Instance::V1::Instance

Returns The instance being created.

Returns:



962
963
964
965
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns The time at which the CreateInstance request was received.

Returns:



962
963
964
965
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end