Class: Google::Cloud::Spanner::Admin::Instance::V1::CreateInstancePartitionMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Instance::V1::CreateInstancePartitionMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb
Overview
Metadata type for the operation returned by CreateInstancePartition.
Instance Attribute Summary collapse
-
#cancel_time ⇒ ::Google::Protobuf::Timestamp
The time at which this operation was cancelled.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time at which this operation failed or was completed successfully.
-
#instance_partition ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::InstancePartition
The instance partition being created.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The time at which the CreateInstancePartition request was received.
Instance Attribute Details
#cancel_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again.
1177 1178 1179 1180 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1177 class CreateInstancePartitionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which this operation failed or was completed successfully.
1177 1178 1179 1180 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1177 class CreateInstancePartitionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_partition ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::InstancePartition
Returns The instance partition being created.
1177 1178 1179 1180 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1177 class CreateInstancePartitionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which the CreateInstancePartition request was received.
1177 1178 1179 1180 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1177 class CreateInstancePartitionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |