Class: Google::Cloud::Spanner::Admin::Instance::V1::InstanceAdmin::Rest::ServiceStub

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb

Overview

REST service stub for the InstanceAdmin service. Service stub contains baseline method implementations including transcoding, making the REST call, and deserialing the response.

Instance Method Summary collapse

Constructor Details

#initialize(endpoint:, credentials:) ⇒ ServiceStub

Returns a new instance of ServiceStub.



35
36
37
38
39
40
41
42
43
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 35

def initialize endpoint:, credentials:
  # These require statements are intentionally placed here to initialize
  # the REST modules only when it's required.
  require "gapic/rest"

  @client_stub = ::Gapic::Rest::ClientStub.new endpoint: endpoint, credentials: credentials,
                                               numeric_enums: true,
                                               raise_faraday_errors: false
end

Instance Method Details

#create_instance(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the create_instance REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 363

def create_instance request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_create_instance_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#create_instance_config(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the create_instance_config REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 135

def create_instance_config request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_create_instance_config_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#delete_instance(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty

Baseline implementation for the delete_instance REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 439

def delete_instance request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_delete_instance_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#delete_instance_config(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty

Baseline implementation for the delete_instance_config REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 211

def delete_instance_config request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_delete_instance_config_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Protobuf::Empty.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#get_iam_policy(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::Policy

Baseline implementation for the get_iam_policy REST call

Parameters:

  • request_pb (::Google::Iam::V1::GetIamPolicyRequest) —

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil) —

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 515

def get_iam_policy request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_get_iam_policy_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Iam::V1::Policy.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#get_instance(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance

Baseline implementation for the get_instance REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 325

def get_instance request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_get_instance_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Spanner::Admin::Instance::V1::Instance.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#get_instance_config(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::InstanceConfig

Baseline implementation for the get_instance_config REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 97

def get_instance_config request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_get_instance_config_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Spanner::Admin::Instance::V1::InstanceConfig.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#list_instance_config_operations(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::ListInstanceConfigOperationsResponse

Baseline implementation for the list_instance_config_operations REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 249

def list_instance_config_operations request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_list_instance_config_operations_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Spanner::Admin::Instance::V1::ListInstanceConfigOperationsResponse.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#list_instance_configs(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::ListInstanceConfigsResponse

Baseline implementation for the list_instance_configs REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 59

def list_instance_configs request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_list_instance_configs_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Spanner::Admin::Instance::V1::ListInstanceConfigsResponse.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#list_instances(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::ListInstancesResponse

Baseline implementation for the list_instances REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 287

def list_instances request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_list_instances_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Cloud::Spanner::Admin::Instance::V1::ListInstancesResponse.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#set_iam_policy(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::Policy

Baseline implementation for the set_iam_policy REST call

Parameters:

  • request_pb (::Google::Iam::V1::SetIamPolicyRequest) —

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil) —

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 477

def set_iam_policy request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_set_iam_policy_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Iam::V1::Policy.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#test_iam_permissions(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Iam::V1::TestIamPermissionsResponse

Baseline implementation for the test_iam_permissions REST call

Parameters:

  • request_pb (::Google::Iam::V1::TestIamPermissionsRequest) —

    A request object representing the call parameters. Required.

  • options (::Gapic::CallOptions) (defaults to: nil) —

    Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 553

def test_iam_permissions request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_test_iam_permissions_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Iam::V1::TestIamPermissionsResponse.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#update_instance(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the update_instance REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 401

def update_instance request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_update_instance_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end

#update_instance_config(request_pb, options = nil) {|result, operation| ... } ⇒ ::Google::Longrunning::Operation

Baseline implementation for the update_instance_config REST call

Parameters:

Yields:

  • (result, operation) —

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::ArgumentError)


173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/google/cloud/spanner/admin/instance/v1/instance_admin/rest/service_stub.rb', line 173

def update_instance_config request_pb, options = nil
  raise ::ArgumentError, "request must be provided" if request_pb.nil?

  verb, uri, query_string_params, body = ServiceStub.transcode_update_instance_config_request request_pb
  query_string_params = if query_string_params.any?
                          query_string_params.to_h { |p| p.split "=", 2 }
                        else
                          {}
                        end

  response = @client_stub.make_http_request(
    verb,
    uri:     uri,
    body:    body || "",
    params:  query_string_params,
    options: options
  )
  operation = ::Gapic::Rest::TransportOperation.new response
  result = ::Google::Longrunning::Operation.decode_json response.body, ignore_unknown_fields: true

  yield result, operation if block_given?
  result
end