Class: Google::Cloud::Spanner::Admin::Instance::V1::UpdateInstancePartitionMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb

Overview

Metadata type for the operation returned by UpdateInstancePartition.

Instance Attribute Summary collapse

Instance Attribute Details

#cancel_time::Google::Protobuf::Timestamp

Returns The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again.

Returns:

  • (::Google::Protobuf::Timestamp)

    The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again.



1273
1274
1275
1276
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1273

class UpdateInstancePartitionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time::Google::Protobuf::Timestamp

Returns The time at which this operation failed or was completed successfully.

Returns:



1273
1274
1275
1276
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1273

class UpdateInstancePartitionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_partition::Google::Cloud::Spanner::Admin::Instance::V1::InstancePartition

Returns The desired end state of the update.

Returns:



1273
1274
1275
1276
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1273

class UpdateInstancePartitionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns The time at which UpdateInstancePartition request was received.

Returns:



1273
1274
1275
1276
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 1273

class UpdateInstancePartitionMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end