Class: Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb
Overview
AsymmetricAutoscalingOption specifies the scaling of replicas identified by the given selection.
Defined Under Namespace
Classes: AutoscalingConfigOverrides
Instance Attribute Summary collapse
-
#overrides ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides
Optional.
-
#replica_selection ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::ReplicaSelection
Required.
Instance Attribute Details
#overrides ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides
Returns Optional. Overrides applied to the top-level autoscaling configuration for the selected replicas.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 381 class AsymmetricAutoscalingOption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Overrides the top-level autoscaling configuration for the replicas # identified by `replica_selection`. All fields in this message are # optional. Any unspecified fields will use the corresponding values from # the top-level autoscaling configuration. # @!attribute [rw] autoscaling_limits # @return [::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingLimits] # Optional. If specified, overrides the min/max limit in the top-level # autoscaling configuration for the selected replicas. # @!attribute [rw] autoscaling_target_high_priority_cpu_utilization_percent # @return [::Integer] # Optional. If specified, overrides the autoscaling target # high_priority_cpu_utilization_percent in the top-level autoscaling # configuration for the selected replicas. # @!attribute [rw] autoscaling_target_total_cpu_utilization_percent # @return [::Integer] # Optional. If specified, overrides the # autoscaling target `total_cpu_utilization_percent` # in the top-level autoscaling configuration for the selected replicas. # @!attribute [rw] disable_high_priority_cpu_autoscaling # @return [::Boolean] # Optional. If true, disables high priority CPU autoscaling for the # selected replicas and ignores # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#high_priority_cpu_utilization_percent high_priority_cpu_utilization_percent} # in the top-level autoscaling configuration. # # When setting this field to true, setting # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_high_priority_cpu_utilization_percent autoscaling_target_high_priority_cpu_utilization_percent} # field to a non-zero value for the same replica is not supported. # # If false, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_high_priority_cpu_utilization_percent autoscaling_target_high_priority_cpu_utilization_percent} # field in the replica will be used if set to a non-zero value. # Otherwise, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#high_priority_cpu_utilization_percent high_priority_cpu_utilization_percent} # field in the top-level autoscaling configuration will be used. # # Setting both # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_high_priority_cpu_autoscaling disable_high_priority_cpu_autoscaling} # and # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_total_cpu_autoscaling disable_total_cpu_autoscaling} # to true for the same replica is not supported. # @!attribute [rw] disable_total_cpu_autoscaling # @return [::Boolean] # Optional. If true, disables total CPU autoscaling for the selected # replicas and ignores # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#total_cpu_utilization_percent total_cpu_utilization_percent} # in the top-level autoscaling configuration. # # When setting this field to true, setting # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_total_cpu_utilization_percent autoscaling_target_total_cpu_utilization_percent} # field to a non-zero value for the same replica is not supported. # # If false, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_total_cpu_utilization_percent autoscaling_target_total_cpu_utilization_percent} # field in the replica will be used if set to a non-zero value. # Otherwise, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#total_cpu_utilization_percent total_cpu_utilization_percent} # field in the top-level autoscaling configuration will be used. # # Setting both # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_high_priority_cpu_autoscaling disable_high_priority_cpu_autoscaling} # and # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_total_cpu_autoscaling disable_total_cpu_autoscaling} # to true for the same replica is not supported. class AutoscalingConfigOverrides include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#replica_selection ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::ReplicaSelection
Returns Required. Selects the replicas to which this AsymmetricAutoscalingOption applies. Only read-only replicas are supported.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 381 class AsymmetricAutoscalingOption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Overrides the top-level autoscaling configuration for the replicas # identified by `replica_selection`. All fields in this message are # optional. Any unspecified fields will use the corresponding values from # the top-level autoscaling configuration. # @!attribute [rw] autoscaling_limits # @return [::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingLimits] # Optional. If specified, overrides the min/max limit in the top-level # autoscaling configuration for the selected replicas. # @!attribute [rw] autoscaling_target_high_priority_cpu_utilization_percent # @return [::Integer] # Optional. If specified, overrides the autoscaling target # high_priority_cpu_utilization_percent in the top-level autoscaling # configuration for the selected replicas. # @!attribute [rw] autoscaling_target_total_cpu_utilization_percent # @return [::Integer] # Optional. If specified, overrides the # autoscaling target `total_cpu_utilization_percent` # in the top-level autoscaling configuration for the selected replicas. # @!attribute [rw] disable_high_priority_cpu_autoscaling # @return [::Boolean] # Optional. If true, disables high priority CPU autoscaling for the # selected replicas and ignores # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#high_priority_cpu_utilization_percent high_priority_cpu_utilization_percent} # in the top-level autoscaling configuration. # # When setting this field to true, setting # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_high_priority_cpu_utilization_percent autoscaling_target_high_priority_cpu_utilization_percent} # field to a non-zero value for the same replica is not supported. # # If false, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_high_priority_cpu_utilization_percent autoscaling_target_high_priority_cpu_utilization_percent} # field in the replica will be used if set to a non-zero value. # Otherwise, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#high_priority_cpu_utilization_percent high_priority_cpu_utilization_percent} # field in the top-level autoscaling configuration will be used. # # Setting both # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_high_priority_cpu_autoscaling disable_high_priority_cpu_autoscaling} # and # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_total_cpu_autoscaling disable_total_cpu_autoscaling} # to true for the same replica is not supported. # @!attribute [rw] disable_total_cpu_autoscaling # @return [::Boolean] # Optional. If true, disables total CPU autoscaling for the selected # replicas and ignores # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#total_cpu_utilization_percent total_cpu_utilization_percent} # in the top-level autoscaling configuration. # # When setting this field to true, setting # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_total_cpu_utilization_percent autoscaling_target_total_cpu_utilization_percent} # field to a non-zero value for the same replica is not supported. # # If false, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#autoscaling_target_total_cpu_utilization_percent autoscaling_target_total_cpu_utilization_percent} # field in the replica will be used if set to a non-zero value. # Otherwise, the # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AutoscalingTargets#total_cpu_utilization_percent total_cpu_utilization_percent} # field in the top-level autoscaling configuration will be used. # # Setting both # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_high_priority_cpu_autoscaling disable_high_priority_cpu_autoscaling} # and # {::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig::AsymmetricAutoscalingOption::AutoscalingConfigOverrides#disable_total_cpu_autoscaling disable_total_cpu_autoscaling} # to true for the same replica is not supported. class AutoscalingConfigOverrides include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |