Class: Google::Cloud::Spanner::Admin::Instance::V1::CreateInstanceMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Instance::V1::CreateInstanceMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb
Overview
Metadata type for the operation returned by CreateInstance.
Instance Attribute Summary collapse
-
#cancel_time ⇒ ::Google::Protobuf::Timestamp
The time at which this operation was cancelled.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time at which this operation failed or was completed successfully.
-
#expected_fulfillment_period ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::FulfillmentPeriod
The expected fulfillment period of this create operation.
-
#instance ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance
The instance being created.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The time at which the CreateInstance request was received.
Instance Attribute Details
#cancel_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again.
962 963 964 965 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962 class CreateInstanceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which this operation failed or was completed successfully.
962 963 964 965 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962 class CreateInstanceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expected_fulfillment_period ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::FulfillmentPeriod
Returns The expected fulfillment period of this create operation.
962 963 964 965 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962 class CreateInstanceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance
Returns The instance being created.
962 963 964 965 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962 class CreateInstanceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which the CreateInstance request was received.
962 963 964 965 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 962 class CreateInstanceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |