Class: Google::Cloud::Spanner::Admin::Instance::V1::Instance
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Instance::V1::Instance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb
Overview
An isolated set of Cloud Spanner resources on which databases can be hosted.
Defined Under Namespace
Modules: DefaultBackupScheduleType, Edition, InstanceType, State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#autoscaling_config ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig
Optional.
-
#config ⇒ ::String
Required.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#default_backup_schedule_type ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::DefaultBackupScheduleType
Optional.
-
#display_name ⇒ ::String
Required.
-
#edition ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::Edition
Optional.
-
#endpoint_uris ⇒ ::Array<::String>
Deprecated.
-
#free_instance_metadata ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::FreeInstanceMetadata
Free instance metadata.
-
#instance_type ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::InstanceType
The
InstanceTypeof the current instance. -
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Cloud Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies.
-
#name ⇒ ::String
Required.
-
#node_count ⇒ ::Integer
The number of nodes allocated to this instance.
-
#processing_units ⇒ ::Integer
The number of processing units allocated to this instance.
-
#replica_compute_capacity ⇒ ::Array<::Google::Cloud::Spanner::Admin::Instance::V1::ReplicaComputeCapacity>
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#autoscaling_config ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::AutoscalingConfig
Returns Optional. The autoscaling configuration. Autoscaling is enabled if this field is set. When autoscaling is enabled, node_count and processing_units are treated as OUTPUT_ONLY fields and reflect the current compute capacity allocated to the instance.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#config ⇒ ::String
Returns Required. The name of the instance's configuration. Values are of the form
projects/<project>/instanceConfigs/<configuration>. See
also InstanceConfig and
ListInstanceConfigs.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the instance was created.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#default_backup_schedule_type ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::DefaultBackupScheduleType
Returns Optional. Controls the default backup schedule behavior for new databases within the instance. By default, a backup schedule is created automatically when a new database is created in a new instance.
Note that the AUTOMATIC value isn't permitted for free instances,
as backups and backup schedules aren't supported for free instances.
In the GetInstance or ListInstances response, if the value of
default_backup_schedule_type isn't set, or set to NONE, Spanner doesn't
create a default backup schedule for new databases in the instance.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#display_name ⇒ ::String
Returns Required. The descriptive name for this instance as it appears in UIs. Must be unique per project and between 4 and 30 characters in length.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#edition ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::Edition
Returns Optional. The Edition of the current instance.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#endpoint_uris ⇒ ::Array<::String>
Returns Deprecated. This field is not populated.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#free_instance_metadata ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::FreeInstanceMetadata
Returns Free instance metadata. Only populated for free instances.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#instance_type ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::InstanceType
Returns The InstanceType of the current instance.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Cloud Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies. Cloud Labels can be used to filter collections of resources. They can be used to control how resource metrics are aggregated. And they can be used as arguments to policy management rules (e.g. route, firewall, load balancing, etc.).
- Label keys must be between 1 and 63 characters long and must conform to
the following regular expression:
[a-z][a-z0-9_-]{0,62}. - Label values must be between 0 and 63 characters long and must conform
to the regular expression
[a-z0-9_-]{0,63}. - No more than 64 labels can be associated with a given resource.
See https://goo.gl/xmQnxf for more information on and examples of labels.
If you plan to use labels in your own code, please note that additional characters may be allowed in the future. And so you are advised to use an internal label representation, such as JSON, which doesn't rely upon specific characters being disallowed. For example, representing labels as the string: name + "" + value would prove problematic if we were to allow "" in a future release.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#name ⇒ ::String
Returns Required. A unique identifier for the instance, which cannot be changed
after the instance is created. Values are of the form
projects/<project>/instances/[a-z][-a-z0-9]*[a-z0-9]. The final
segment of the name must be between 2 and 64 characters in length.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#node_count ⇒ ::Integer
Returns The number of nodes allocated to this instance. At most, one of either
node_count or processing_units should be present in the message.
Users can set the node_count field to specify the target number of nodes
allocated to the instance.
If autoscaling is enabled, node_count is treated as an OUTPUT_ONLY
field and reflects the current number of nodes allocated to the instance.
This might be zero in API responses for instances that are not yet in the
READY state.
For more information, see Compute capacity, nodes, and processing units.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#processing_units ⇒ ::Integer
Returns The number of processing units allocated to this instance. At most, one of
either processing_units or node_count should be present in the message.
Users can set the processing_units field to specify the target number of
processing units allocated to the instance.
If autoscaling is enabled, processing_units is treated as an
OUTPUT_ONLY field and reflects the current number of processing units
allocated to the instance.
This might be zero in API responses for instances that are not yet in the
READY state.
For more information, see Compute capacity, nodes and processing units.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#replica_compute_capacity ⇒ ::Array<::Google::Cloud::Spanner::Admin::Instance::V1::ReplicaComputeCapacity> (readonly)
Returns Output only. Lists the compute capacity per ReplicaSelection. A replica selection identifies a set of replicas with common properties. Replicas identified by a ReplicaSelection are scaled with the same compute capacity.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#state ⇒ ::Google::Cloud::Spanner::Admin::Instance::V1::Instance::State (readonly)
Returns Output only. The current instance state. For
CreateInstance,
the state must be either omitted or set to CREATING. For
UpdateInstance,
the state must be either omitted or set to READY.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the instance was most recently updated.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 581 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the current state of the instance. module State # Not specified. STATE_UNSPECIFIED = 0 # The instance is still being created. Resources may not be # available yet, and operations such as database creation may not # work. CREATING = 1 # The instance is fully created and ready to do work such as # creating databases. READY = 2 end # The type of this instance. The type can be used to distinguish product # variants, that can affect aspects like: usage restrictions, quotas and # billing. Currently this is used to distinguish FREE_INSTANCE vs PROVISIONED # instances. module InstanceType # Not specified. INSTANCE_TYPE_UNSPECIFIED = 0 # Provisioned instances have dedicated resources, standard usage limits and # support. PROVISIONED = 1 # Free instances provide no guarantee for dedicated resources, # [node_count, processing_units] should be 0. They come # with stricter usage limits and limited support. FREE_INSTANCE = 2 end # The edition selected for this instance. Different editions provide # different capabilities at different price points. module Edition # Edition not specified. EDITION_UNSPECIFIED = 0 # Standard edition. STANDARD = 1 # Enterprise edition. ENTERPRISE = 2 # Enterprise Plus edition. ENTERPRISE_PLUS = 3 end # Indicates the # [default backup # schedule](https://cloud.google.com/spanner/docs/backup#default-backup-schedules) # behavior for new databases within the instance. module DefaultBackupScheduleType # Not specified. DEFAULT_BACKUP_SCHEDULE_TYPE_UNSPECIFIED = 0 # A default backup schedule isn't created automatically when a new database # is created in the instance. NONE = 1 # A default backup schedule is created automatically when a new database # is created in the instance. The default backup schedule creates a full # backup every 24 hours. These full backups are retained for 7 days. # You can edit or delete the default backup schedule once it's created. AUTOMATIC = 2 end end |