Class: Google::Cloud::Spanner::Admin::Instance::V1::ListInstancesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::Admin::Instance::V1::ListInstancesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb
Overview
The request for ListInstances.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
An expression for filtering the results of the request.
-
#page_size ⇒ ::Integer
Number of instances to be returned in the response.
-
#page_token ⇒ ::String
If non-empty,
page_tokenshould contain a next_page_token from a previous ListInstancesResponse. -
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns An expression for filtering the results of the request. Filter rules are case insensitive. The fields eligible for filtering are:
* `name`
* `display_name`
* `labels.key` where key is the name of a label
Some examples of using filters are:
* `name:*` --> The instance has a name.
* `name:Howl` --> The instance's name contains the string "howl".
* `name:HOWL` --> Equivalent to above.
* `NAME:howl` --> Equivalent to above.
* `labels.env:*` --> The instance has the label "env".
* `labels.env:dev` --> The instance has the label "env" and the value of
the label contains the string "dev".
* `name:howl labels.env:dev` --> The instance's name contains "howl" and
it has the label "env" with its value
containing "dev".
582 583 584 585 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 582 class ListInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Number of instances to be returned in the response. If 0 or less, defaults to the server's maximum allowed page size.
582 583 584 585 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 582 class ListInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns If non-empty, page_token should contain a
next_page_token
from a previous
ListInstancesResponse.
582 583 584 585 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 582 class ListInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the project for which a list of instances is
requested. Values are of the form projects/<project>.
582 583 584 585 |
# File 'proto_docs/google/spanner/admin/instance/v1/spanner_instance_admin.rb', line 582 class ListInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |